#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# @autor: Ramón Invarato Menéndez
# @version 1.0

import doctest

if __name__ == "__main__":
    doctest.testfile("../easy_binary_file/easy_binary_file.py")
